
Q1SS: Experimental development of Quantum 1-Shot Signatures
===========================================================

This library contains experiments in Quantum 1-Shot Signatures,
with particular focus on applications to blockchain technology.

Modules of interest:

- The :mod:`q1ss.binalg` module contains binary linear algebra primitives used
  by the remainder of the library.
- The :mod:`q1ss.ap` module contains implementations of affine partition functions.

Further modules are in development for the construction, optimisation and
obfuscation of binary circuits and quantum oracles, as well as quantum
resource estimation.


GitHub repo: https://github.com/The-QSig-Commission/q1ss


.. toctree::
    :maxdepth: 3
    :caption: Contents

    getting-started

.. include:: api-toc.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
